Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(239)

Unified Diff: remoting/host/client_session_unittest.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/host/clipboard_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/client_session_unittest.cc
diff --git a/remoting/host/client_session_unittest.cc b/remoting/host/client_session_unittest.cc
index 5bd4ca2148035650d379cc224a6122ac43805f52..0f0898e2a30e7c01570aa55ca7b4a09b85151251 100644
--- a/remoting/host/client_session_unittest.cc
+++ b/remoting/host/client_session_unittest.cc
@@ -224,7 +224,7 @@ void ClientSessionTest::SetUp() {
void ClientSessionTest::TearDown() {
// Clear out |task_runner_| reference so the loop can quit, and run it until
// it does.
- task_runner_ = NULL;
+ task_runner_ = nullptr;
run_loop_.Run();
}
@@ -236,9 +236,9 @@ void ClientSessionTest::CreateClientSession() {
EXPECT_CALL(*session, SetEventHandler(_));
// Mock protocol::ConnectionToClient APIs called directly by ClientSession.
// HostStub is not touched by ClientSession, so we can safely pass NULL.
scoped_ptr<MockConnectionToClient> connection(
- new MockConnectionToClient(session, NULL));
+ new MockConnectionToClient(session, nullptr));
EXPECT_CALL(*connection, session()).WillRepeatedly(Return(session));
EXPECT_CALL(*connection, client_stub())
.WillRepeatedly(Return(&client_stub_));
@@ -257,7 +257,7 @@ void ClientSessionTest::CreateClientSession() {
connection.Pass(),
desktop_environment_factory_.get(),
base::TimeDelta(),
- NULL,
+ nullptr,
extensions_));
}
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/host/clipboard_mac.mm » ('j') | no next file with comments »
@@ -236,9 +236,9 @@ void ClientSessionTest::CreateClientSession() {
EXPECT_CALL(*session, SetEventHandler(_));
// Mock protocol::ConnectionToClient APIs called directly by ClientSession.
- // HostStub is not touched by ClientSession, so we can safely pass NULL.
+ // HostStub is not touched by ClientSession, so we can safely pass nullptr.
scoped_ptr<MockConnectionToClient> connection(

Powered by Google App Engine
This is Rietveld 408576698